@@ -338,7 +338,13 @@ class CloudWatchLogsAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchLogsAction.__init__)
+            def stub(
+                log_group: aws_cdk.aws_logs.ILogGroup,
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
         props = CloudWatchLogsActionProps(role=role)
 
@@ -353,7 +359,9 @@ class CloudWatchLogsAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchLogsAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -424,7 +432,9 @@ class CloudWatchPutMetricAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchPutMetricAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -484,7 +494,15 @@ class CloudWatchSetAlarmStateAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateAction.__init__)
+            def stub(
+                alarm: aws_cdk.aws_cloudwatch.IAlarm,
+                *,
+                alarm_state_to_set: aws_cdk.aws_cloudwatch.AlarmState,
+                reason: typing.Optional[builtins.str] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alarm", value=alarm, expected_type=type_hints["alarm"])
         props = CloudWatchSetAlarmStateActionProps(
             alarm_state_to_set=alarm_state_to_set, reason=reason, role=role
@@ -504,7 +522,9 @@ class CloudWatchSetAlarmStateAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateAction.bind)
+            def stub(topic_rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument topic_rule", value=topic_rule, expected_type=type_hints["topic_rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [topic_rule]))
 
@@ -537,7 +557,9 @@ class CommonActionProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CommonActionProps.__init__)
+            def stub(*, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
@@ -615,7 +637,15 @@ class FirehosePutRecordAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirehosePutRecordAction.__init__)
+            def stub(
+                stream: aws_cdk.aws_kinesisfirehose.IDeliveryStream,
+                *,
+                batch_mode: typing.Optional[builtins.bool] = None,
+                record_separator: typing.Optional["FirehoseRecordSeparator"] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = FirehosePutRecordActionProps(
             batch_mode=batch_mode, record_separator=record_separator, role=role
@@ -632,7 +662,9 @@ class FirehosePutRecordAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirehosePutRecordAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -685,7 +717,14 @@ class FirehosePutRecordActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FirehosePutRecordActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                batch_mode: typing.Optional[builtins.bool] = None,
+                record_separator: typing.Optional["FirehoseRecordSeparator"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument batch_mode", value=batch_mode, expected_type=type_hints["batch_mode"])
             check_type(argname="argument record_separator", value=record_separator, expected_type=type_hints["record_separator"])
@@ -834,7 +873,14 @@ class IotRepublishMqttAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotRepublishMqttAction.__init__)
+            def stub(
+                topic: builtins.str,
+                *,
+                quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         props = IotRepublishMqttActionProps(
             quality_of_service=quality_of_service, role=role
@@ -851,7 +897,9 @@ class IotRepublishMqttAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotRepublishMqttAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -888,7 +936,13 @@ class IotRepublishMqttActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotRepublishMqttActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument quality_of_service", value=quality_of_service, expected_type=type_hints["quality_of_service"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -974,7 +1028,14 @@ class KinesisPutRecordAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisPutRecordAction.__init__)
+            def stub(
+                stream: aws_cdk.aws_kinesis.IStream,
+                *,
+                partition_key: builtins.str,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = KinesisPutRecordActionProps(partition_key=partition_key, role=role)
 
@@ -989,7 +1050,9 @@ class KinesisPutRecordAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisPutRecordAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -1031,7 +1094,13 @@ class KinesisPutRecordActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisPutRecordActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                partition_key: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument partition_key", value=partition_key, expected_type=type_hints["partition_key"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -1110,7 +1179,9 @@ class LambdaFunctionAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaFunctionAction.__init__)
+            def stub(func: aws_cdk.aws_lambda.IFunction) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument func", value=func, expected_type=type_hints["func"])
         jsii.create(self.__class__, self, [func])
 
@@ -1126,7 +1197,9 @@ class LambdaFunctionAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaFunctionAction.bind)
+            def stub(topic_rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument topic_rule", value=topic_rule, expected_type=type_hints["topic_rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [topic_rule]))
 
@@ -1210,7 +1283,15 @@ class S3PutObjectAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3PutObjectAction.__init__)
+            def stub(
+                bucket: aws_cdk.aws_s3.IBucket,
+                *,
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                key: typing.Optional[builtins.str] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         props = S3PutObjectActionProps(
             access_control=access_control, key=key, role=role
@@ -1227,7 +1308,9 @@ class S3PutObjectAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3PutObjectAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -1268,7 +1351,14 @@ class S3PutObjectActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3PutObjectActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                key: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
@@ -1408,7 +1498,14 @@ class SnsTopicAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsTopicAction.__init__)
+            def stub(
+                topic: aws_cdk.aws_sns.ITopic,
+                *,
+                message_format: typing.Optional[SnsActionMessageFormat] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         props = SnsTopicActionProps(message_format=message_format, role=role)
 
@@ -1423,7 +1520,9 @@ class SnsTopicAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsTopicAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -1465,7 +1564,13 @@ class SnsTopicActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsTopicActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                message_format: typing.Optional[SnsActionMessageFormat] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument message_format", value=message_format, expected_type=type_hints["message_format"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -1553,7 +1658,14 @@ class SqsQueueAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsQueueAction.__init__)
+            def stub(
+                queue: aws_cdk.aws_sqs.IQueue,
+                *,
+                use_base64: typing.Optional[builtins.bool] = None,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         props = SqsQueueActionProps(use_base64=use_base64, role=role)
 
@@ -1568,7 +1680,9 @@ class SqsQueueAction(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsQueueAction.bind)
+            def stub(rule: aws_cdk.aws_iot.ITopicRule) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
@@ -1610,7 +1724,13 @@ class SqsQueueActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SqsQueueActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                use_base64: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument use_base64", value=use_base64, expected_type=type_hints["use_base64"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -1681,7 +1801,9 @@ class CloudWatchLogsActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchLogsActionProps.__init__)
+            def stub(*, role: typing.Optional[aws_cdk.aws_iam.IRole] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
@@ -1761,7 +1883,17 @@ class CloudWatchPutMetricActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchPutMetricActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                metric_name: builtins.str,
+                metric_namespace: builtins.str,
+                metric_unit: builtins.str,
+                metric_value: builtins.str,
+                metric_timestamp: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument metric_name", value=metric_name, expected_type=type_hints["metric_name"])
             check_type(argname="argument metric_namespace", value=metric_namespace, expected_type=type_hints["metric_namespace"])
@@ -1922,7 +2054,14 @@ class CloudWatchSetAlarmStateActionProps(CommonActionProps):
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateActionProps.__init__)
+            def stub(
+                *,
+                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                alarm_state_to_set: aws_cdk.aws_cloudwatch.AlarmState,
+                reason: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument alarm_state_to_set", value=alarm_state_to_set, expected_type=type_hints["alarm_state_to_set"])
             check_type(argname="argument reason", value=reason, expected_type=type_hints["reason"])
